@@ -815,6 +815,32 @@ Summary: if the dynaloading on your system requires some kind of C<-fPIC> flag,
 
 ).
 
+=item isprime() is a misnomer before PARI version 2.3
+
+In older versions of PARI, the one-argument variant of the function isprime()
+is actually checking for probable primes.  Moreover, it has certain problems.
+
+B<POSSIBLE WORKAROUND:> before version 2.3 of PARI, to get probability of
+misdetecting a prime below 1e-12, call isprime() twice; below 1e-18, call
+it 3 times; etc.
+
+The problems: first, the default algorithm (before version 2.3) is looking for so-called
+"witnesses" (with up to 10 tries) among random integers; usually, witnesses are abundant.  However,
+there are non-prime numbers for which the fraction of witnesses is close to the theoretical
+miminum, 0.25; during 10 calls, the probability
+of missing a witness for such numbers is close to 1e-6.
+
+Second, the random number generator is reset when PARI library
+is initialized.  That means that one can find non-primes which will
+trigger a false positive on the Nth call to isprime() (for particular values
+of N).  With enough computing resources, one can find non-primes for which N is
+relatively small (there are relatively small examples with N about 1000).
+Compare with similar examples for simpler algorith,
+L<Carmichael numbers|http://primes.utm.edu/glossary/xpage/CarmichaelNumber.html>;
+see also L<numbers with few witnesses|http://oeis.org/A141768>.
+
+See L<the discussion of isprime()|https://rt.cpan.org/Public/Bug/Display.html?id=93652>.
+
 =back
 
 =head1 INITIALIZATION
@@ -926,7 +952,7 @@ sub _shiftr {
 $initmem ||= 4000000;		# How much memory for the stack
 $initprimes ||= 500000;		# Calculate primes up to this number
 
-$VERSION = '2.01080605';
+$VERSION = '2.01080606';
 
 my $true = 1;
 # Propagate sv_true, sv_false to SvIOK:
