@@ -193,7 +193,7 @@ sub ll_ftp () {	# All Perl download failures I saw are on Linux and BSD.
 user anonymous auto-download-Math-Pari@cpan.org
 cd /pub/pari/unix/
 dir
-cd OLD
+cd OLD/2.1
 dir
 binary
 get pari-2.1.7.tgz
@@ -301,7 +301,7 @@ EOP
     }
 
     $base_url = "ftp://$host$dir";
-    my @extra_chdir = qw(OLD);
+    my @extra_chdir = qw(OLD/2.3 ../2.1 ..);
     print "Getting GP/PARI from $base_url\n";
 
     eval {
@@ -481,14 +481,14 @@ sub patches_for ($) {
 			      'patches/diff_2.1.6_no-common'],
 		 '2.1.7' =>  [
 			($^O =~ /darwin/i ? 'patches/diff_2.1.6_no-common' : ()),
-			($^O eq 'MSWin32' ? 'patches/diff_2.1.7_mingw-w64' : ()),
+			($^O =~ /^MSWin32\b/ ? 'patches/diff_2.1.7_mingw-w64' : ()),
 			      'patches/patch-pari-unnormalized-float',
 			      'patches/diff_2.1.7_-O',
 			      'patches/diff_2.1.7_div',
 			      'patches/diff_2.1.6_align_power_of_2',
 			      'patches/diff_2.1.7_restart'],
 		 '2.3.5' =>  [
-			($^O eq 'MSWin32' ? 'patches/diff_2.3.5_mingw-w64' : ())], 
+			($^O =~ /^MSWin32\b/ ? 'patches/diff_2.3.5_mingw-w64' : ())], 
 		);
   print "Looking for patches for $v...\n";
   my @p = $patches{$v} ? @{$patches{$v}} : ();
@@ -661,7 +661,7 @@ sub find_paricfg {
 
   # Probably not present in newer versions anymore...
   unshift @paricfg, "$paridir/win32/paricfg.h"
-    if $^O eq 'MSWin32' and -f "$paridir/win32/paricfg.h";
+    if $^O =~ /^MSWin32\b/ and -f "$paridir/win32/paricfg.h";
   @paricfg;
 }
 
@@ -900,7 +900,7 @@ sub find_machine_architecture () {
 	   or $os eq 'freebsd' or $os =~ /^cygwin/) {
     chomp($machine = `uname -m`);
     $machine ||= 'ix86';
-  } elsif (($Config{archname} eq 'MSWin32-x86-multi-thread') && ($Config{cc} =~ /gcc/)) {
+  } elsif (($Config{archname} =~ /^MSWin32-x86\b/) && ($Config{cc} =~ /gcc/) and ($Config{longsize} == 4)) {
     $machine = 'ix86';
   } elsif (0 and $os =~ /win32/i and not $Config{gccversion}) {
     # Not needed with rename of kernel1.s to kernel1.c?
@@ -980,6 +980,7 @@ sub find_machine_architecture () {
     $machine = $1;
   } elsif (not defined $machine) {
     chomp($machine = `uname -m`);
+    $machine =~ s/\s+$//;		# trailing \cM on cygwin ???
   }
   $machine =~ s/[ix]\d86(-\w+)?/ix86/ if defined $machine;	# i686-pc
 
